@@ -1,13 +1,13 @@
-from enum import Enum
 import importlib
 from abc import ABCMeta, abstractmethod
 
-from typing import Dict, List, Union, Optional, Iterable, Tuple
+from typing import Dict, List, Union, Optional, Tuple
 from dataclasses import dataclass
 from pydantic import BaseModel, Field
 from sklearn.pipeline import Pipeline
 from sklearn.compose import ColumnTransformer, TransformedTargetRegressor
 from skopt.searchcv import BayesSearchCV
+from skopt.space import Integer, Categorical, Real
 
 Numeric = Union[float, int]
 
@@ -26,14 +26,15 @@ class _ColumnTransformerInput:
     features: List[str]
 
     def to_raw(self) -> Tuple:
+        """
+        This returns the raw values needed for the ColumnTransformer or the Pipeline
+        :return: The raw values
+        """
         if self.features is None:
-            if self.name is None:
-                return (self.sk_obj)
-            else:
-                return (
-                    self.name,
-                    self.sk_obj
-                )
+            return (
+                self.name,
+                self.sk_obj
+            )
         else:
             return (
                 self.name,
@@ -51,7 +52,7 @@ class BaseParamModel(BaseModel, metaclass=ABCMeta):
     name: str
 
     @abstractmethod
-    def to_param(self) -> Iterable:
+    def to_param(self):
         """
         The abstract class to get the parameter space with the current distribution
         :return: The skopt parameter
@@ -67,12 +68,29 @@ class CategoricalParamModel(BaseParamModel):
     """
     categories: List
 
-    def to_param(self) -> List:
+    def to_param(self):
         """
         This converts the param to what skopt needs
-        :return:
+
+        :return: The categorical
         """
-        return self.categories
+        return Categorical(self.categories)
+
+
+class UniformlyDistributedIntegerParamModel(BaseParamModel):
+    """
+    This is for the uniform integer distribution
+    """
+    lowInt: int
+    highInt: int
+
+    def to_param(self):
+        """
+        This converts the param to what skopt needs
+
+        :return: The integer parameter
+        """
+        return Integer(self.lowInt, self.highInt)
 
 
 class NumericParamModel(BaseParamModel, metaclass=ABCMeta):
@@ -97,7 +115,7 @@ class UniformlyDistributedParamModel(NumericParamModel):
     low: Numeric
     high: Numeric
 
-    def to_param(self) -> Tuple:
+    def to_param(self):
         """
         This converts the param to what skopt needs
 
@@ -109,10 +127,10 @@ class UniformlyDistributedParamModel(NumericParamModel):
         else:
             d = "uniform"
 
-        return (
+        return Real(
             self.low,
             self.high,
-            d
+            prior=d
         )
 
 
@@ -131,6 +149,7 @@ class NormallyDistributedParamModel(NumericParamModel):
     def to_param(self) -> Tuple:
         """
         This converts the param to what skopt needs
+
         :return: The skopt parameter
         """
 
@@ -160,7 +179,8 @@ class SklearnTransformerModel(BaseModel):
             Union[
                 NormallyDistributedParamModel,
                 UniformlyDistributedParamModel,
-                CategoricalParamModel
+                CategoricalParamModel,
+                UniformlyDistributedIntegerParamModel
             ]
         ]
     ] = Field(None)
@@ -168,6 +188,7 @@ class SklearnTransformerModel(BaseModel):
     def to_model(self):
         """
         This performs the import of the scikit-learn transformer
+
         :return: The sklearn object
         """
         if "sklearn" in self.name:
@@ -187,6 +208,7 @@ class SklearnTransformerModel(BaseModel):
     def get_parameter_space(self, prefix: Optional[str] = None):
         """
         This gets the parameter space of the transformer
+
         :return: The parameter search
         """
 
@@ -219,6 +241,7 @@ class FeaturePodModel(BaseModel):
     def to_sklearn_pipeline(self) -> _ColumnTransformerInput:
         """
         This creates the sklearn pipeline for the features in the pod
+
         :return:
         """
         steps = []
@@ -241,7 +264,9 @@ class FeaturePodModel(BaseModel):
     def to_param_search_space(self, prefix: str) -> Dict:
         """
         This creates the full parameter space for the pod
+
         :param prefix:
+
         :return:
         """
         res_params = dict()
